"use strict";
/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodePushDeploymentReleasesImpl = void 0;
const coreClient = require("@azure/core-client");
const Mappers = require("../models/mappers");
const Parameters = require("../models/parameters");
/** Class containing CodePushDeploymentReleases operations. */
class CodePushDeploymentReleasesImpl {
    /**
     * Initialize a new instance of the class CodePushDeploymentReleases class.
     * @param client Reference to the service client
     */
    constructor(client) {
        this.client = client;
    }
    /**
     * Clears a Deployment of releases
     * @param deploymentName deployment name
     * @param ownerName The name of the owner
     * @param appName The name of the application
     * @param options The options parameters.
     */
    delete(deploymentName, ownerName, appName, options) {
        return this.client.sendOperationRequest({ deploymentName, ownerName, appName, options }, deleteOperationSpec);
    }
    /**
     * Gets the history of releases on a Deployment
     * @param deploymentName deployment name
     * @param ownerName The name of the owner
     * @param appName The name of the application
     * @param options The options parameters.
     */
    get(deploymentName, ownerName, appName, options) {
        return this.client.sendOperationRequest({ deploymentName, ownerName, appName, options }, getOperationSpec);
    }
    /**
     * Create a new CodePush release for the specified deployment
     * @param deploymentName deployment name
     * @param ownerName The name of the owner
     * @param appName The name of the application
     * @param uploadedRelease The necessary information required to download the bundle and being the
     *                        release process.
     * @param options The options parameters.
     */
    create(deploymentName, ownerName, appName, uploadedRelease, options) {
        return this.client.sendOperationRequest({ deploymentName, ownerName, appName, uploadedRelease, options }, createOperationSpec);
    }
}
exports.CodePushDeploymentReleasesImpl = CodePushDeploymentReleasesImpl;
// Operation Specifications
const serializer = coreClient.createSerializer(Mappers, /* isXml */ false);
const deleteOperationSpec = {
    path: "/v0.1/apps/{owner_name}/{app_name}/deployments/{deployment_name}/releases",
    httpMethod: "DELETE",
    responses: {
        204: {},
        default: {
            bodyMapper: Mappers.Paths2Uoo4MV01AppsOwnerNameAppNameDeploymentsDeploymentNameReleasesDeleteResponsesDefaultContentApplicationJsonSchema
        }
    },
    urlParameters: [
        Parameters.$host,
        Parameters.ownerName,
        Parameters.appName,
        Parameters.deploymentName
    ],
    headerParameters: [Parameters.accept],
    serializer
};
const getOperationSpec = {
    path: "/v0.1/apps/{owner_name}/{app_name}/deployments/{deployment_name}/releases",
    httpMethod: "GET",
    responses: {
        200: {
            bodyMapper: {
                type: {
                    name: "Sequence",
                    element: {
                        type: {
                            name: "Composite",
                            className: "PathsJ4L197V01AppsOwnerNameAppNameDeploymentsDeploymentNameReleasesGetResponses200ContentApplicationJsonSchemaItems"
                        }
                    }
                }
            }
        },
        default: {
            bodyMapper: Mappers.PathsSxykieV01AppsOwnerNameAppNameDeploymentsDeploymentNameReleasesGetResponsesDefaultContentApplicationJsonSchema
        }
    },
    urlParameters: [
        Parameters.$host,
        Parameters.ownerName,
        Parameters.appName,
        Parameters.deploymentName
    ],
    headerParameters: [Parameters.accept],
    serializer
};
const createOperationSpec = {
    path: "/v0.1/apps/{owner_name}/{app_name}/deployments/{deployment_name}/releases",
    httpMethod: "POST",
    responses: {
        201: {
            bodyMapper: Mappers.Paths1N68We7V01AppsOwnerNameAppNameDeploymentsDeploymentNameReleasesPostResponses201ContentApplicationJsonSchema
        },
        default: {
            bodyMapper: Mappers.PathsWqgstxV01AppsOwnerNameAppNameDeploymentsDeploymentNameReleasesPostResponsesDefaultContentApplicationJsonSchema
        }
    },
    requestBody: Parameters.uploadedRelease,
    urlParameters: [
        Parameters.$host,
        Parameters.ownerName,
        Parameters.appName,
        Parameters.deploymentName
    ],
    headerParameters: [Parameters.contentType, Parameters.accept],
    mediaType: "json",
    serializer
};
